@@ -21,16 +21,18 @@
 """Module for P2PKH address encoding/decoding."""
 
 # Imports
-from enum import auto, Enum, unique
+from enum import Enum, auto, unique
 from typing import Any, Union
+
 from bip_utils.addr.addr_dec_utils import AddrDecUtils
 from bip_utils.addr.addr_key_validator import AddrKeyValidator
 from bip_utils.addr.iaddr_decoder import IAddrDecoder
 from bip_utils.addr.iaddr_encoder import IAddrEncoder
 from bip_utils.base58 import Base58Alphabets, Base58ChecksumError, Base58Decoder, Base58Encoder
-from bip_utils.bech32 import Bech32ChecksumError, BchBech32Decoder, BchBech32Encoder
+from bip_utils.bech32 import BchBech32Decoder, BchBech32Encoder, Bech32ChecksumError
 from bip_utils.ecc import IPublicKey
-from bip_utils.utils.misc import BytesUtils, CryptoUtils
+from bip_utils.utils.crypto import Hash160
+from bip_utils.utils.misc import BytesUtils
 
 
 @unique
@@ -57,8 +59,8 @@ class P2PKHAddrDecoder(IAddrDecoder):
             addr (str): Address string
 
         Other Parameters:
-            net_ver (bytes)                        : Net address version
-            base58_alph (Base58Alphabets, optional): Base58 alphabet, Bitcoin alphabet by default
+            net_ver (bytes)                        : Expected net address version
+            base58_alph (Base58Alphabets, optional): Base58 alphabet (default: Bitcoin alphabet)
 
         Returns:
             bytes: Public key hash bytes
@@ -76,7 +78,7 @@ class P2PKHAddrDecoder(IAddrDecoder):
         else:
             # Validate length
             AddrDecUtils.ValidateLength(addr_dec_bytes,
-                                        CryptoUtils.Hash160DigestSize() + len(net_ver_bytes))
+                                        Hash160.DigestSize() + len(net_ver_bytes))
             # Validate and remove prefix
             return AddrDecUtils.ValidateAndRemovePrefix(addr_dec_bytes, net_ver_bytes)
 
@@ -117,14 +119,7 @@ class P2PKHAddrEncoder(IAddrEncoder):
                          if pub_key_mode == P2PKHPubKeyModes.COMPRESSED
                          else pub_key_obj.RawUncompressed().ToBytes())
 
-        return Base58Encoder.CheckEncode(net_ver_bytes + CryptoUtils.Hash160(pub_key_bytes), base58_alph)
-
-
-class P2PKHAddr(P2PKHAddrEncoder):
-    """
-    P2PKH address class.
-    Only kept for compatibility, P2PKHAddrEncoder shall be used instead.
-    """
+        return Base58Encoder.CheckEncode(net_ver_bytes + Hash160.QuickDigest(pub_key_bytes), base58_alph)
 
 
 class BchP2PKHAddrDecoder(IAddrDecoder):
@@ -143,8 +138,8 @@ class BchP2PKHAddrDecoder(IAddrDecoder):
             addr (str): Address string
 
         Other Parameters:
-            hrp (str)      : HRP
-            net_ver (bytes): Net address version
+            hrp (str)      : Expected HRP
+            net_ver (bytes): Expected net address version
 
         Returns:
             bytes: Public key hash bytes
@@ -166,7 +161,7 @@ class BchP2PKHAddrDecoder(IAddrDecoder):
                                  f"got {BytesUtils.ToHexString(net_ver_bytes_got)})")
             # Validate length
             AddrDecUtils.ValidateLength(addr_dec_bytes,
-                                        CryptoUtils.Hash160DigestSize())
+                                        Hash160.DigestSize())
             return addr_dec_bytes
 
 
@@ -202,11 +197,9 @@ class BchP2PKHAddrEncoder(IAddrEncoder):
         pub_key_obj = AddrKeyValidator.ValidateAndGetSecp256k1Key(pub_key)
         return BchBech32Encoder.Encode(hrp,
                                        net_ver_bytes,
-                                       CryptoUtils.Hash160(pub_key_obj.RawCompressed().ToBytes()))
+                                       Hash160.QuickDigest(pub_key_obj.RawCompressed().ToBytes()))
 
 
-class BchP2PKHAddr(BchP2PKHAddrEncoder):
-    """
-    Bitcoin Cash P2PKH address.
-    Only kept for compatibility, BchP2PKHAddrEncoder shall be used instead.
-    """
+# Deprecated: only for compatibility, Encoder classes shall be used instead
+P2PKHAddr = P2PKHAddrEncoder
+BchP2PKHAddr = BchP2PKHAddrEncoder
