@@ -22,6 +22,7 @@
 
 # Imports
 from typing import Any, Union
+
 from bip_utils.addr.addr_key_validator import AddrKeyValidator
 from bip_utils.addr.iaddr_decoder import IAddrDecoder
 from bip_utils.addr.iaddr_encoder import IAddrEncoder
@@ -29,7 +30,7 @@ from bip_utils.addr.P2PKH_addr import BchP2PKHAddrDecoder, P2PKHAddrDecoder
 from bip_utils.base58 import Base58Encoder
 from bip_utils.bech32 import BchBech32Encoder
 from bip_utils.ecc import IPublicKey
-from bip_utils.utils.misc import CryptoUtils
+from bip_utils.utils.crypto import Hash160
 
 
 class P2SHAddrConst:
@@ -55,11 +56,11 @@ class _P2SHAddrUtils:
         """
 
         # Key hash: Hash160(public_key)
-        key_hash_bytes = CryptoUtils.Hash160(pub_key.RawCompressed().ToBytes())
+        key_hash_bytes = Hash160.QuickDigest(pub_key.RawCompressed().ToBytes())
         # Script signature: 0x0014 | Hash160(public_key)
         script_sig_bytes = P2SHAddrConst.SCRIPT_BYTES + key_hash_bytes
         # Address bytes = Hash160(script_signature)
-        return CryptoUtils.Hash160(script_sig_bytes)
+        return Hash160.QuickDigest(script_sig_bytes)
 
 
 class P2SHAddrDecoder(IAddrDecoder):
@@ -78,7 +79,7 @@ class P2SHAddrDecoder(IAddrDecoder):
             addr (str): Address string
 
         Other Parameters:
-            net_ver (bytes): Net address version
+            net_ver (bytes): Expected net address version
 
         Returns:
             bytes: Script signature hash bytes
@@ -122,13 +123,6 @@ class P2SHAddrEncoder(IAddrEncoder):
         return Base58Encoder.CheckEncode(net_ver_bytes + _P2SHAddrUtils.AddScriptSig(pub_key_obj))
 
 
-class P2SHAddr(P2SHAddrEncoder):
-    """
-    P2SH address class.
-    Only kept for compatibility, P2SHAddrEncoder shall be used instead.
-    """
-
-
 class BchP2SHAddrDecoder(IAddrDecoder):
     """
     Bitcoin Cash P2SH address decoder class.
@@ -145,8 +139,8 @@ class BchP2SHAddrDecoder(IAddrDecoder):
             addr (str): Address string
 
         Other Parameters:
-            hrp (str)      : HRP
-            net_ver (bytes): Net address version
+            hrp (str)      : Expected HRP
+            net_ver (bytes): Expected net address version
 
         Returns:
             bytes: Script signature hash bytes
@@ -192,8 +186,6 @@ class BchP2SHAddrEncoder(IAddrEncoder):
         return BchBech32Encoder.Encode(hrp, net_ver_bytes, _P2SHAddrUtils.AddScriptSig(pub_key_obj))
 
 
-class BchP2SHAddr(BchP2SHAddrEncoder):
-    """
-    Bitcoin Cash P2SH address class.
-    Only kept for compatibility, BchP2SHAddrEncoder shall be used instead.
-    """
+# Deprecated: only for compatibility, Encoder classes shall be used instead
+P2SHAddr = P2SHAddrEncoder
+BchP2SHAddr = BchP2SHAddrEncoder
