@@ -22,12 +22,14 @@
 
 # Imports
 from typing import Any, Union
+
 from bip_utils.addr.addr_dec_utils import AddrDecUtils
 from bip_utils.addr.addr_key_validator import AddrKeyValidator
 from bip_utils.addr.iaddr_decoder import IAddrDecoder
 from bip_utils.addr.iaddr_encoder import IAddrEncoder
 from bip_utils.ecc import Ed25519PublicKey, IPublicKey
-from bip_utils.utils.misc import Base32Decoder, Base32Encoder, CryptoUtils
+from bip_utils.utils.crypto import Sha512_256
+from bip_utils.utils.misc import Base32Decoder, Base32Encoder
 
 
 class AlgoAddrConst:
@@ -51,7 +53,7 @@ class _AlgoAddrUtils:
         Returns:
             bytes: Computed checksum
         """
-        return CryptoUtils.Sha512_256(pub_key_bytes)[-1 * AlgoAddrConst.CHECKSUM_BYTE_LEN:]
+        return Sha512_256.QuickDigest(pub_key_bytes)[-1 * AlgoAddrConst.CHECKSUM_BYTE_LEN:]
 
 
 class AlgoAddrDecoder(IAddrDecoder):
@@ -126,8 +128,5 @@ class AlgoAddrEncoder(IAddrEncoder):
         return Base32Encoder.EncodeNoPadding(pub_key_bytes + checksum_bytes)
 
 
-class AlgoAddr(AlgoAddrEncoder):
-    """
-    Algorand address class.
-    Only kept for compatibility, AlgoAddrEncoder shall be used instead.
-    """
+# Deprecated: only for compatibility, Encoder class shall be used instead
+AlgoAddr = AlgoAddrEncoder
