@@ -22,13 +22,15 @@
 
 # Imports
 from typing import Any, Union
+
 from bip_utils.addr.addr_dec_utils import AddrDecUtils
 from bip_utils.addr.addr_key_validator import AddrKeyValidator
 from bip_utils.addr.iaddr_decoder import IAddrDecoder
 from bip_utils.addr.iaddr_encoder import IAddrEncoder
 from bip_utils.coin_conf import CoinsConf
 from bip_utils.ecc import Ed25519Blake2bPublicKey, IPublicKey
-from bip_utils.utils.misc import Base32Decoder, Base32Encoder, BytesUtils, CryptoUtils
+from bip_utils.utils.crypto import Blake2b40
+from bip_utils.utils.misc import Base32Decoder, Base32Encoder, BytesUtils
 
 
 class NanoAddrConst:
@@ -40,8 +42,6 @@ class NanoAddrConst:
     PAYLOAD_PAD_DEC: bytes = b"\x00\x00\x00"
     # Payload padding (encoded)
     PAYLOAD_PAD_ENC: str = "1111"
-    # Checksum length in bytes
-    CHECKSUM_BYTE_LEN: int = 5
 
 
 class _NanoAddrUtils:
@@ -58,8 +58,7 @@ class _NanoAddrUtils:
         Returns:
             bytes: Computed checksum
         """
-        return BytesUtils.Reverse(CryptoUtils.Blake2b(pub_key_bytes,
-                                                      digest_size=NanoAddrConst.CHECKSUM_BYTE_LEN))
+        return BytesUtils.Reverse(Blake2b40.QuickDigest(pub_key_bytes))
 
 
 class NanoAddrDecoder(IAddrDecoder):
@@ -87,19 +86,20 @@ class NanoAddrDecoder(IAddrDecoder):
 
         # Validate and remove prefix
         addr_no_prefix = AddrDecUtils.ValidateAndRemovePrefix(addr,
-                                                              CoinsConf.Nano.Params("addr_prefix"))
+                                                              CoinsConf.Nano.ParamByKey("addr_prefix"))
         # Decode from base32
         addr_dec_bytes = Base32Decoder.Decode(NanoAddrConst.PAYLOAD_PAD_ENC + addr_no_prefix,
                                               NanoAddrConst.BASE32_ALPHABET)
         # Validate length
         AddrDecUtils.ValidateLength(addr_dec_bytes,
-                                    Ed25519Blake2bPublicKey.CompressedLength() + NanoAddrConst.CHECKSUM_BYTE_LEN
+                                    Ed25519Blake2bPublicKey.CompressedLength() + Blake2b40.DigestSize()
                                     + len(NanoAddrConst.PAYLOAD_PAD_DEC) - 1)
 
         # Get back checksum and public key bytes
         pub_key_bytes, checksum_bytes = AddrDecUtils.SplitPartsByChecksum(
             addr_dec_bytes[len(NanoAddrConst.PAYLOAD_PAD_DEC):],
-            NanoAddrConst.CHECKSUM_BYTE_LEN)
+            Blake2b40.DigestSize()
+        )
         # Validate checksum
         AddrDecUtils.ValidateChecksum(pub_key_bytes, checksum_bytes, _NanoAddrUtils.ComputeChecksum)
         # Validate public key
@@ -141,11 +141,8 @@ class NanoAddrEncoder(IAddrEncoder):
         b32_enc = Base32Encoder.EncodeNoPadding(payload_bytes, NanoAddrConst.BASE32_ALPHABET)
 
         # Add prefix
-        return CoinsConf.Nano.Params("addr_prefix") + b32_enc[len(NanoAddrConst.PAYLOAD_PAD_ENC):]
+        return CoinsConf.Nano.ParamByKey("addr_prefix") + b32_enc[len(NanoAddrConst.PAYLOAD_PAD_ENC):]
 
 
-class NanoAddr(NanoAddrEncoder):
-    """
-    Nano address class.
-    Only kept for compatibility, NanoAddrEncoder shall be used instead.
-    """
+# Deprecated: only for compatibility, Encoder class shall be used instead
+NanoAddr = NanoAddrEncoder
