@@ -23,12 +23,14 @@
 # Imports
 from enum import IntEnum, unique
 from typing import Any, Union
+
 from bip_utils.addr.addr_dec_utils import AddrDecUtils
 from bip_utils.addr.addr_key_validator import AddrKeyValidator
 from bip_utils.addr.iaddr_decoder import IAddrDecoder
 from bip_utils.addr.iaddr_encoder import IAddrEncoder
 from bip_utils.ecc import Ed25519PublicKey, IPublicKey
-from bip_utils.utils.misc import Base32Decoder, Base32Encoder, BytesUtils, CryptoUtils, IntegerUtils
+from bip_utils.utils.crypto import XModemCrc
+from bip_utils.utils.misc import Base32Decoder, Base32Encoder, BytesUtils, IntegerUtils
 
 
 @unique
@@ -60,7 +62,7 @@ class _XlmAddrUtils:
         Returns:
             bytes: Computed checksum
         """
-        return BytesUtils.Reverse(CryptoUtils.XModemCrc(payload_bytes))
+        return BytesUtils.Reverse(XModemCrc.QuickDigest(payload_bytes))
 
 
 class XlmAddrDecoder(IAddrDecoder):
@@ -79,7 +81,7 @@ class XlmAddrDecoder(IAddrDecoder):
             addr (str): Address string
 
         Other Parameters:
-            addr_type (XlmAddrTypes): Address type
+            addr_type (XlmAddrTypes): Expected address type (default: public key)
 
         Returns:
             bytes: Public key bytes
@@ -90,7 +92,7 @@ class XlmAddrDecoder(IAddrDecoder):
         """
 
         # Get and check address type
-        addr_type = kwargs["addr_type"]
+        addr_type = kwargs.get("addr_type", XlmAddrTypes.PUB_KEY)
         if not isinstance(addr_type, XlmAddrTypes):
             raise TypeError("Address type is not an enumerative of XlmAddrTypes")
 
@@ -133,7 +135,7 @@ class XlmAddrEncoder(IAddrEncoder):
             pub_key (bytes or IPublicKey): Public key bytes or object
 
         Other Parameters:
-            addr_type (XlmAddrTypes): Address type
+            addr_type (XlmAddrTypes): Address type (default: public key)
 
         Returns:
             str: Address string
@@ -144,7 +146,7 @@ class XlmAddrEncoder(IAddrEncoder):
         """
 
         # Get and check address type
-        addr_type = kwargs["addr_type"]
+        addr_type = kwargs.get("addr_type", XlmAddrTypes.PUB_KEY)
         if not isinstance(addr_type, XlmAddrTypes):
             raise TypeError("Address type is not an enumerative of XlmAddrTypes")
 
@@ -158,8 +160,5 @@ class XlmAddrEncoder(IAddrEncoder):
         return Base32Encoder.EncodeNoPadding(payload_bytes + checksum_bytes)
 
 
-class XlmAddr(XlmAddrEncoder):
-    """
-    Stellar address class.
-    Only kept for compatibility, XlmAddrEncoder shall be used instead.
-    """
+# Deprecated: only for compatibility, Encoder class shall be used instead
+XlmAddr = XlmAddrEncoder
