@@ -22,6 +22,7 @@
 
 # Imports
 from typing import Any, Union
+
 from bip_utils.addr.iaddr_decoder import IAddrDecoder
 from bip_utils.addr.iaddr_encoder import IAddrEncoder
 from bip_utils.addr.P2PKH_addr import P2PKHAddrDecoder, P2PKHAddrEncoder
@@ -55,7 +56,7 @@ class XrpAddrDecoder(IAddrDecoder):
 
         # Ripple address is just a P2PKH address with a different Base58 alphabet
         return P2PKHAddrDecoder.DecodeAddr(addr,
-                                           net_ver=CoinsConf.Ripple.Params("p2pkh_net_ver"),
+                                           net_ver=CoinsConf.Ripple.ParamByKey("p2pkh_net_ver"),
                                            base58_alph=Base58Alphabets.RIPPLE)
 
 
@@ -85,12 +86,9 @@ class XrpAddrEncoder(IAddrEncoder):
 
         # Ripple address is just a P2PKH address with a different Base58 alphabet
         return P2PKHAddrEncoder.EncodeKey(pub_key,
-                                          net_ver=CoinsConf.Ripple.Params("p2pkh_net_ver"),
+                                          net_ver=CoinsConf.Ripple.ParamByKey("p2pkh_net_ver"),
                                           base58_alph=Base58Alphabets.RIPPLE)
 
 
-class XrpAddr(XrpAddrEncoder):
-    """
-    Ripple address class.
-    Only kept for compatibility, XrpAddrEncoder shall be used instead.
-    """
+# Deprecated: only for compatibility, Encoder class shall be used instead
+XrpAddr = XrpAddrEncoder
