@@ -1,5 +1,5 @@
 from bip_utils.algorand.mnemonic.algorand_entropy_generator import AlgorandEntropyBitLen, AlgorandEntropyGenerator
-from bip_utils.algorand.mnemonic.algorand_mnemonic import AlgorandLanguages, AlgorandWordsNum, AlgorandMnemonic
+from bip_utils.algorand.mnemonic.algorand_mnemonic import AlgorandLanguages, AlgorandMnemonic, AlgorandWordsNum
 from bip_utils.algorand.mnemonic.algorand_mnemonic_decoder import AlgorandMnemonicDecoder
 from bip_utils.algorand.mnemonic.algorand_mnemonic_encoder import AlgorandMnemonicEncoder
 from bip_utils.algorand.mnemonic.algorand_mnemonic_generator import AlgorandMnemonicGenerator
