@@ -22,10 +22,11 @@
 
 # Import
 from __future__ import annotations
-from typing import Iterator, List, Sequence, Tuple, Union
+
+from typing import Iterator, List, Optional, Sequence, Tuple, Union
+
 from bip_utils.bip.bip32.bip32_ex import Bip32PathError
 from bip_utils.bip.bip32.bip32_key_data import Bip32KeyIndex
-from bip_utils.bip.bip32.bip32_utils import Bip32Utils
 
 
 class Bip32PathConst:
@@ -47,17 +48,19 @@ class Bip32Path:
     m_is_absolute: bool
 
     def __init__(self,
-                 elems: Sequence[Union[int, Bip32KeyIndex]],
-                 is_absolute: bool) -> None:
+                 elems: Optional[Sequence[Union[int, Bip32KeyIndex]]] = None,
+                 is_absolute: bool = True) -> None:
         """
         Construct class.
 
         Args:
-            elems (list)      : Path elements
-            is_absolute (bool): True if path is an absolute one, false otherwise
+            elems (list, optional)      : Path elements (default: empty)
+            is_absolute (bool, optional): True if path is an absolute one, false otherwise (default: True)
         """
         try:
-            self.m_elems = [Bip32KeyIndex(elem) if isinstance(elem, int) else elem for elem in elems]
+            self.m_elems = ([]
+                            if elems is None
+                            else [Bip32KeyIndex(elem) if isinstance(elem, int) else elem for elem in elems])
         except ValueError as ex:
             raise Bip32PathError("The path contains some invalid key indexes") from ex
 
@@ -120,7 +123,7 @@ class Bip32Path:
             if not elem.IsHardened():
                 path_str += f"{str(elem.ToInt())}/"
             else:
-                path_str += f"{str(Bip32Utils.UnhardenIndex(elem.ToInt()))}'/"
+                path_str += f"{str(Bip32KeyIndex.UnhardenIndex(elem.ToInt()))}'/"
 
         return path_str[:-1]
 
@@ -241,4 +244,4 @@ class Bip32PathParser:
         if not path_elem.isnumeric():
             raise Bip32PathError(f"Invalid path element ({path_elem})")
 
-        return int(path_elem) if not is_hardened else Bip32Utils.HardenIndex(int(path_elem))
+        return int(path_elem) if not is_hardened else Bip32KeyIndex.HardenIndex(int(path_elem))
