@@ -1,4 +1,4 @@
 from bip_utils.bip.bip32.kholaw.bip32_kholaw_ed25519 import Bip32Ed25519Kholaw, Bip32KholawEd25519
-from bip_utils.bip.bip32.kholaw.bip32_kholaw_key_derivator import Bip32KholawEd25519KeyDerivator
+from bip_utils.bip.bip32.kholaw.bip32_kholaw_ed25519_key_derivator import Bip32KholawEd25519KeyDerivator
 from bip_utils.bip.bip32.kholaw.bip32_kholaw_key_derivator_base import Bip32KholawEd25519KeyDerivatorBase
 from bip_utils.bip.bip32.kholaw.bip32_kholaw_mst_key_generator import Bip32KholawEd25519MstKeyGenerator
