@@ -21,8 +21,9 @@
 """Module for BIP39 mnemonic."""
 
 # Imports
-from enum import auto, IntEnum, unique
+from enum import IntEnum, auto, unique
 from typing import Dict, List, Union
+
 from bip_utils.utils.misc import StringUtils
 from bip_utils.utils.mnemonic import Mnemonic, MnemonicLanguages
 
@@ -66,7 +67,7 @@ class Bip39MnemonicConst:
     ]
 
     # Language files
-    LANGUAGE_FILES: Dict[Bip39Languages, str] = {
+    LANGUAGE_FILES: Dict[MnemonicLanguages, str] = {
         Bip39Languages.ENGLISH: "wordlist/english.txt",
         Bip39Languages.ITALIAN: "wordlist/italian.txt",
         Bip39Languages.FRENCH: "wordlist/french.txt",
