@@ -23,15 +23,17 @@
 
 # Imports
 from __future__ import annotations
+
 from abc import ABC, abstractmethod
 from enum import IntEnum, unique
 from functools import lru_cache
 from typing import Union
-from bip_utils.bip.bip32 import Bip32Base, Bip32Utils, Bip32KeyData
+
+from bip_utils.bip.bip32 import Bip32Base, Bip32KeyData, Bip32KeyIndex
 from bip_utils.bip.bip44_base.bip44_base_ex import Bip44DepthError
-from bip_utils.bip.bip44_base.bip44_keys import Bip44PublicKey, Bip44PrivateKey
-from bip_utils.bip.conf.common import BipCoins, BipCoinConf
-from bip_utils.ecc import IPublicKey, IPrivateKey
+from bip_utils.bip.bip44_base.bip44_keys import Bip44PrivateKey, Bip44PublicKey
+from bip_utils.bip.conf.common import BipCoinConf, BipCoins
+from bip_utils.ecc import IPrivateKey, IPublicKey
 
 
 @unique
@@ -61,7 +63,7 @@ class Bip44Base(ABC):
     The class is meant to be derived by classes implementing BIP44 or its extensions.
     """
 
-    m_bip32: Bip32Base
+    m_bip32_obj: Bip32Base
     m_coin_conf: BipCoinConf
 
     #
@@ -74,8 +76,6 @@ class Bip44Base(ABC):
                   coin_conf: BipCoinConf) -> Bip44Base:
         """
         Create a Bip44Base object from the specified seed (e.g. BIP39 seed).
-        The test net flag is automatically set when the coin is derived. However, if you want to get the correct master
-        or purpose keys, you have to specify here if it's a test net.
 
         Args:
             seed_bytes (bytes)     : Seed bytes
@@ -173,26 +173,26 @@ class Bip44Base(ABC):
     #
 
     def __init__(self,
-                 bip32: Bip32Base,
+                 bip32_obj: Bip32Base,
                  coin_conf: BipCoinConf) -> None:
         """
         Construct class.
 
         Args:
-            bip32 (Bip32Base object): Bip32Base object
-            coin_conf (BipCoinConf) : BipCoinConf object
+            bip32_obj (Bip32Base object): Bip32Base object
+            coin_conf (BipCoinConf)     : BipCoinConf object
 
         Returns:
             Bip44DepthError: If the Bip32 object depth is not valid
         """
-        depth = bip32.Depth()
+        depth = bip32_obj.Depth()
 
         # If the Bip32 is public-only, the depth shall start from the account level because hardened derivation is
         # used below it, which is not possible with public keys
-        if bip32.IsPublicOnly():
+        if bip32_obj.IsPublicOnly():
             if depth < Bip44Levels.ACCOUNT or depth > Bip44Levels.ADDRESS_INDEX:
                 raise Bip44DepthError(
-                    f"Depth of the public-only Bip32 object ({depth}) is below account level or "
+                    f"Depth of the public-only Bip object ({depth}) is below account level or "
                     f"beyond address index level"
                 )
         # If the Bip32 object is not public-only, any depth is fine as long as it is not greater
@@ -200,11 +200,11 @@ class Bip44Base(ABC):
         else:
             if depth < 0 or depth > Bip44Levels.ADDRESS_INDEX:
                 raise Bip44DepthError(
-                    f"Depth of the Bip32 object ({depth}) is invalid or beyond address index level"
+                    f"Depth of the Bip object ({depth}) is invalid or beyond address index level"
                 )
 
         # Finally, initialize class
-        self.m_bip32 = bip32
+        self.m_bip32_obj = bip32_obj
         self.m_coin_conf = coin_conf
 
     @lru_cache()
@@ -215,7 +215,7 @@ class Bip44Base(ABC):
         Returns:
             Bip44PublicKey object: Bip44PublicKey object
         """
-        return Bip44PublicKey(self.m_bip32.PublicKey(),
+        return Bip44PublicKey(self.m_bip32_obj.PublicKey(),
                               self.m_coin_conf)
 
     @lru_cache()
@@ -229,7 +229,7 @@ class Bip44Base(ABC):
         Raises:
             Bip32KeyError: If the Bip32 object is public-only
         """
-        return Bip44PrivateKey(self.m_bip32.PrivateKey(),
+        return Bip44PrivateKey(self.m_bip32_obj.PrivateKey(),
                                self.m_coin_conf)
 
     def Bip32Object(self) -> Bip32Base:
@@ -239,7 +239,7 @@ class Bip44Base(ABC):
         Returns:
             Bip32Base object: Bip32Base object
         """
-        return self.m_bip32
+        return self.m_bip32_obj
 
     def CoinConf(self) -> BipCoinConf:
         """
@@ -257,12 +257,21 @@ class Bip44Base(ABC):
         Returns:
             bool: True if public-only, false otherwise
         """
-        return self.m_bip32.IsPublicOnly()
+        return self.m_bip32_obj.IsPublicOnly()
+
+    def Level(self) -> Bip44Levels:
+        """
+        Return the current level.
+
+        Returns:
+            Bip44Levels: Current level
+        """
+        return Bip44Levels(self.m_bip32_obj.Depth().ToInt())
 
     def IsLevel(self,
                 level: Bip44Levels) -> bool:
         """
-        Return if the current depth is the specified one.
+        Return if the current level is the specified one.
 
         Args:
             level (Bip44Levels): Level to be checked
@@ -275,24 +284,11 @@ class Bip44Base(ABC):
         """
         if not isinstance(level, Bip44Levels):
             raise TypeError("Level is not an enumerative of Bip44Levels")
+        return self.m_bip32_obj.Depth() == level
 
-        return self.m_bip32.Depth() == level
-
-    #
-    # Protected class methods
-    #
-
-    @classmethod
-    def _DeriveDefaultPathGeneric(cls,
-                                  bip_obj: Bip44Base,
-                                  purpose: int) -> Bip44Base:
+    def DeriveDefaultPath(self) -> Bip44Base:
         """
         Derive the default coin path and return a new Bip44Base object.
-        It shall be called from a child class.
-
-        Args:
-            bip_obj (Bip44Base object): Bip44Base object
-            purpose (int)             : Purpose
 
         Returns:
             Bip44Base object: Bip44Base object
@@ -301,30 +297,25 @@ class Bip44Base(ABC):
             Bip44DepthError: If the current depth is not suitable for deriving keys
             Bip32KeyError: If the derivation results in an invalid key
         """
-        if not cls.IsLevel(bip_obj, Bip44Levels.MASTER):
-            raise Bip44DepthError(
-                f"Current depth ({bip_obj.m_bip32.Depth().ToInt()}) is not suitable for deriving default path"
-            )
-
         # Derive purpose and coin by default
-        bip_obj = cls._PurposeGeneric(bip_obj, purpose)
-        bip_obj = cls._CoinGeneric(bip_obj)
+        bip_obj = self.Purpose().Coin()
 
         # Derive the remaining path
-        return cls(bip_obj.m_bip32.DerivePath(bip_obj.m_coin_conf.DefaultPath()),
-                   bip_obj.m_coin_conf)
+        return self.__class__(bip_obj.m_bip32_obj.DerivePath(bip_obj.m_coin_conf.DefaultPath()),
+                              bip_obj.m_coin_conf)
 
-    @classmethod
-    def _PurposeGeneric(cls,
-                        bip_obj: Bip44Base,
+    #
+    # Protected class methods
+    #
+
+    def _PurposeGeneric(self,
                         purpose: int) -> Bip44Base:
         """
         Derive a child key from the purpose and return a new Bip44Base object.
         It shall be called from a child class.
 
         Args:
-            bip_obj (Bip44Base object): Bip44Base object
-            purpose (int)             : Purpose
+            purpose (int): Purpose
 
         Returns:
             Bip44Base object: Bip44Base object
@@ -333,24 +324,19 @@ class Bip44Base(ABC):
             Bip44DepthError: If the current depth is not suitable for deriving keys
             Bip32KeyError: If the derivation results in an invalid key
         """
-        if not cls.IsLevel(bip_obj, Bip44Levels.MASTER):
+        if not self.IsLevel(Bip44Levels.MASTER):
             raise Bip44DepthError(
-                f"Current depth ({bip_obj.m_bip32.Depth().ToInt()}) is not suitable for deriving purpose"
+                f"Current depth ({self.m_bip32_obj.Depth().ToInt()}) is not suitable for deriving purpose"
             )
 
-        return cls(bip_obj.m_bip32.ChildKey(purpose),
-                   bip_obj.m_coin_conf)
+        return self.__class__(self.m_bip32_obj.ChildKey(purpose),
+                              self.m_coin_conf)
 
-    @classmethod
-    def _CoinGeneric(cls,
-                     bip_obj: Bip44Base) -> Bip44Base:
+    def _CoinGeneric(self) -> Bip44Base:
         """
         Derive a child key from the coin type specified at construction and return a new Bip44Base object.
         It shall be called from a child class.
 
-        Args:
-            bip_obj (Bip44Base object): Bip44Base object
-
         Returns:
             Bip44Base object: Bip44Base object
 
@@ -358,27 +344,24 @@ class Bip44Base(ABC):
             Bip44DepthError: If the current depth is not suitable for deriving keys
             Bip32KeyError: If the derivation results in an invalid key
         """
-        if not cls.IsLevel(bip_obj, Bip44Levels.PURPOSE):
+        if not self.IsLevel(Bip44Levels.PURPOSE):
             raise Bip44DepthError(
-                f"Current depth ({bip_obj.m_bip32.Depth().ToInt()}) is not suitable for deriving coin"
+                f"Current depth ({self.m_bip32_obj.Depth().ToInt()}) is not suitable for deriving coin"
             )
 
-        coin_idx = bip_obj.m_coin_conf.CoinIndex()
+        coin_idx = self.m_coin_conf.CoinIndex()
 
-        return cls(bip_obj.m_bip32.ChildKey(Bip32Utils.HardenIndex(coin_idx)),
-                   bip_obj.m_coin_conf)
+        return self.__class__(self.m_bip32_obj.ChildKey(Bip32KeyIndex.HardenIndex(coin_idx)),
+                              self.m_coin_conf)
 
-    @classmethod
-    def _AccountGeneric(cls,
-                        bip_obj: Bip44Base,
+    def _AccountGeneric(self,
                         acc_idx: int) -> Bip44Base:
         """
         Derive a child key from the specified account index and return a new Bip44Base object.
         It shall be called from a child class.
 
         Args:
-            bip_obj (Bip44Base object): Bip44Base object
-            acc_idx (int)             : Account index
+            acc_idx (int): Account index
 
         Returns:
             Bip44Base object: Bip44Base object
@@ -387,62 +370,56 @@ class Bip44Base(ABC):
             Bip44DepthError: If the current depth is not suitable for deriving keys
             Bip32KeyError: If the derivation results in an invalid key
         """
-        if not cls.IsLevel(bip_obj, Bip44Levels.COIN):
+        if not self.IsLevel(Bip44Levels.COIN):
             raise Bip44DepthError(
-                f"Current depth ({bip_obj.m_bip32.Depth().ToInt()}) is not suitable for deriving account"
+                f"Current depth ({self.m_bip32_obj.Depth().ToInt()}) is not suitable for deriving account"
             )
 
-        return cls(bip_obj.m_bip32.ChildKey(Bip32Utils.HardenIndex(acc_idx)),
-                   bip_obj.m_coin_conf)
+        return self.__class__(self.m_bip32_obj.ChildKey(Bip32KeyIndex.HardenIndex(acc_idx)),
+                              self.m_coin_conf)
 
-    @classmethod
-    def _ChangeGeneric(cls,
-                       bip_obj: Bip44Base,
+    def _ChangeGeneric(self,
                        change_type: Bip44Changes) -> Bip44Base:
         """
-        Derive a child key from the specified chain type and return a new Bip44Base object.
+        Derive a child key from the specified change type and return a new Bip44Base object.
         It shall be called from a child class.
 
         Args:
-            bip_obj (Bip44Base object): Bip44Base object
             change_type (Bip44Changes): Change type, must a Bip44Changes enum
 
         Returns:
             Bip44Base object: Bip44Base object
 
         Raises:
-            TypeError: If chain index is not a Bip44Changes enum
+            TypeError: If change type is not a Bip44Changes enum
             Bip44DepthError: If the current depth is not suitable for deriving keys
             Bip32KeyError: If the derivation results in an invalid key
         """
         if not isinstance(change_type, Bip44Changes):
             raise TypeError("Change index is not an enumerative of Bip44Changes")
 
-        if not cls.IsLevel(bip_obj, Bip44Levels.ACCOUNT):
+        if not self.IsLevel(Bip44Levels.ACCOUNT):
             raise Bip44DepthError(
-                f"Current depth ({bip_obj.m_bip32.Depth().ToInt()}) is not suitable for deriving change"
+                f"Current depth ({self.m_bip32_obj.Depth().ToInt()}) is not suitable for deriving change"
             )
 
         # Use hardened derivation if not-hardended is not supported
-        if not bip_obj.m_bip32.IsPrivateUnhardenedDerivationSupported():
-            change_idx = Bip32Utils.HardenIndex(int(change_type))
+        if not self.m_bip32_obj.IsPublicDerivationSupported():
+            change_idx = Bip32KeyIndex.HardenIndex(int(change_type))
         else:
             change_idx = int(change_type)
 
-        return cls(bip_obj.m_bip32.ChildKey(change_idx),
-                   bip_obj.m_coin_conf)
+        return self.__class__(self.m_bip32_obj.ChildKey(change_idx),
+                              self.m_coin_conf)
 
-    @classmethod
-    def _AddressIndexGeneric(cls,
-                             bip_obj: Bip44Base,
+    def _AddressIndexGeneric(self,
                              addr_idx: int) -> Bip44Base:
         """
         Derive a child key from the specified address index and return a new Bip44Base object.
         It shall be called from a child class.
 
         Args:
-            bip_obj (Bip44Base object): Bip44Base object
-            addr_idx (int)            : Address index
+            addr_idx (int): Address index
 
         Returns:
             Bip44Base object: Bip44Base object
@@ -451,17 +428,17 @@ class Bip44Base(ABC):
             Bip44DepthError: If the current depth is not suitable for deriving keys
             Bip32KeyError: If the derivation results in an invalid key
         """
-        if not cls.IsLevel(bip_obj, Bip44Levels.CHANGE):
+        if not self.IsLevel(Bip44Levels.CHANGE):
             raise Bip44DepthError(
-                f"Current depth ({bip_obj.m_bip32.Depth().ToInt()}) is not suitable for deriving address"
+                f"Current depth ({self.m_bip32_obj.Depth().ToInt()}) is not suitable for deriving address"
             )
 
         # Use hardened derivation if not-hardended is not supported
-        if not bip_obj.m_bip32.IsPrivateUnhardenedDerivationSupported():
-            addr_idx = Bip32Utils.HardenIndex(addr_idx)
+        if not self.m_bip32_obj.IsPublicDerivationSupported():
+            addr_idx = Bip32KeyIndex.HardenIndex(addr_idx)
 
-        return cls(bip_obj.m_bip32.ChildKey(addr_idx),
-                   bip_obj.m_coin_conf)
+        return self.__class__(self.m_bip32_obj.ChildKey(addr_idx),
+                              self.m_coin_conf)
 
     #
     # Abstract methods
@@ -558,25 +535,10 @@ class Bip44Base(ABC):
             Bip32KeyError: If the key is not valid
         """
 
-    @abstractmethod
-    def DeriveDefaultPath(self) -> Bip44Base:
-        """
-        Derive the default coin path and return a new Bip44Base object.
-        It calls the underlying _DeriveDefaultPathGeneric method with the current object as parameter.
-
-        Returns:
-            Bip44Base object: Bip44Base object
-
-        Raises:
-            Bip44DepthError: If the current depth is not suitable for deriving keys
-            Bip32KeyError: If the derivation results in an invalid key
-        """
-
     @abstractmethod
     def Purpose(self) -> Bip44Base:
         """
         Derive a child key from the purpose and return a new Bip44Base object.
-        It calls the underlying _PurposeGeneric method with the current object as parameter.
 
         Returns:
             Bip44Base object: Bip44Base object
@@ -590,7 +552,6 @@ class Bip44Base(ABC):
     def Coin(self) -> Bip44Base:
         """
         Derive a child key from the coin type specified at construction and return a new Bip44Base object.
-        It calls the underlying _CoinGeneric method with the current object as parameter.
 
         Returns:
             Bip44Base object: Bip44Base object
@@ -605,7 +566,6 @@ class Bip44Base(ABC):
                 acc_idx: int) -> Bip44Base:
         """
         Derive a child key from the specified account index and return a new Bip44Base object.
-        It calls the underlying _AccountGeneric method with the current object as parameter.
 
         Args:
             acc_idx (int): Account index
@@ -623,7 +583,6 @@ class Bip44Base(ABC):
                change_type: Bip44Changes) -> Bip44Base:
         """
         Derive a child key from the specified change type and return a new Bip44Base object.
-        It calls the underlying _ChangeGeneric method with the current object as parameter.
 
         Args:
             change_type (Bip44Changes): Change type, must a Bip44Changes enum
@@ -632,7 +591,7 @@ class Bip44Base(ABC):
             Bip44Base object: Bip44Base object
 
         Raises:
-            TypeError: If chain index is not a Bip44Changes enum
+            TypeError: If change type is not a Bip44Changes enum
             Bip44DepthError: If current depth is not suitable for deriving keys
             Bip32KeyError: If the derivation results in an invalid key
         """
@@ -642,7 +601,6 @@ class Bip44Base(ABC):
                      addr_idx: int) -> Bip44Base:
         """
         Derive a child key from the specified address index and return a new Bip44Base object.
-        It calls the underlying _AddressIndexGeneric method with the current object as parameter.
 
         Args:
             addr_idx (int): Address index
