@@ -1,5 +1,5 @@
-from bip_utils.bip.conf.common.bip_conf_const import HARDENED_DEF_PATH, NOT_HARDENED_DEF_PATH
-from bip_utils.bip.conf.common.bip_coins import BipCoins
-from bip_utils.bip.conf.common.bip_coin_conf import BipCoinConf
 from bip_utils.bip.conf.common.bip_bitcoin_cash_conf import BipBitcoinCashConf
+from bip_utils.bip.conf.common.bip_coin_conf import BipCoinConf, BipCoinFctCallsConf
+from bip_utils.bip.conf.common.bip_coins import BipCoins
+from bip_utils.bip.conf.common.bip_conf_const import HARDENED_DEF_PATH, NOT_HARDENED_DEF_PATH
 from bip_utils.bip.conf.common.bip_litecoin_conf import BipLitecoinConf
