@@ -25,6 +25,7 @@ from bip_utils.coin_conf.coin_conf import CoinConf
 from bip_utils.slip.slip173 import Slip173
 from bip_utils.utils.conf import CoinNames
 
+
 # Bitcoin constants used by different coins
 # Main net
 _BTC_P2PKH_NET_VER_MN: bytes = b"\x00"
@@ -445,6 +446,14 @@ class CoinsConf:
         params={},
     )
 
+    # Configuration for Icon
+    Icon: CoinConf = CoinConf(
+        coin_name=CoinNames("Icon", "ICX"),
+        params={
+            "addr_prefix": "hx",
+        },
+    )
+
     # Configuration for IRISnet
     IrisNet: CoinConf = CoinConf(
         coin_name=CoinNames("IRIS Network", "IRIS"),
