@@ -1,4 +1,4 @@
-# Copyright (c) 2021 Emanuele Bellocchia
+# Copyright (c) 2022 Emanuele Bellocchia
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -38,10 +38,8 @@ class Ed25519KeysConst:
 
     # Public key prefix
     PUB_KEY_PREFIX: bytes = b"\x00"
-    # Compressed public key length in bytes
-    PUB_KEY_COMPRESSED_BYTE_LEN: int = 33
-    # Uncompressed public key length in bytes
-    PUB_KEY_UNCOMPRESSED_BYTE_LEN: int = 33
+    # Public key length in bytes
+    PUB_KEY_BYTE_LEN: int = 32
     # Private key length in bytes
     PRIV_KEY_BYTE_LEN: int = 32
 
@@ -68,15 +66,13 @@ class Ed25519PublicKey(IPublicKey):
         """
 
         # Remove the 0x00 prefix if present because nacl requires 32-byte length
-        if (len(key_bytes) == cls.CompressedLength()
+        if (len(key_bytes) == Ed25519KeysConst.PUB_KEY_BYTE_LEN + len(Ed25519KeysConst.PUB_KEY_PREFIX)
                 and key_bytes[0] == BytesUtils.ToInteger(Ed25519KeysConst.PUB_KEY_PREFIX)):
             key_bytes = key_bytes[1:]
 
         # nacl doesn't check if the point lies on curve
-        try:
-            ed25519_lib.point_decode(key_bytes)
-        except ValueError as ex:
-            raise ValueError("Invalid public key bytes") from ex
+        if not ed25519_lib.point_is_on_curve(key_bytes):
+            raise ValueError("Invalid public key bytes")
 
         try:
             return cls(signing.VerifyKey(key_bytes))
@@ -128,7 +124,7 @@ class Ed25519PublicKey(IPublicKey):
         Returns:
            int: Compressed key length
         """
-        return Ed25519KeysConst.PUB_KEY_COMPRESSED_BYTE_LEN
+        return Ed25519KeysConst.PUB_KEY_BYTE_LEN + len(Ed25519KeysConst.PUB_KEY_PREFIX)
 
     @staticmethod
     def UncompressedLength() -> int:
@@ -138,7 +134,7 @@ class Ed25519PublicKey(IPublicKey):
         Returns:
            int: Uncompressed key length
         """
-        return Ed25519KeysConst.PUB_KEY_UNCOMPRESSED_BYTE_LEN
+        return Ed25519PublicKey.CompressedLength()
 
     def UnderlyingObject(self) -> Any:
         """
