@@ -1,4 +1,4 @@
-# Copyright (c) 2021 Emanuele Bellocchia
+# Copyright (c) 2022 Emanuele Bellocchia
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -21,11 +21,11 @@
 """Module for ed25519 point."""
 
 # Imports
-from typing import Any
+from typing import Any, Optional
 
 from bip_utils.ecc.common.ipoint import IPoint
 from bip_utils.ecc.curve.elliptic_curve_types import EllipticCurveTypes
-from bip_utils.ecc.ed25519.lib import ed25519_lib, ed25519_nacl_wrapper
+from bip_utils.ecc.ed25519.lib import ed25519_lib
 from bip_utils.utils.misc import DataBytes
 
 
@@ -39,7 +39,10 @@ class Ed25519PointConst:
 class Ed25519Point(IPoint):
     """Ed25519 point class."""
 
-    m_point: bytes
+    m_is_generator: bool
+    m_enc_bytes: bytes
+    m_x: Optional[int]
+    m_y: Optional[int]
 
     @classmethod
     def FromBytes(cls,
@@ -53,19 +56,13 @@ class Ed25519Point(IPoint):
         Returns:
             IPoint: IPoint object
         """
-        if len(point_bytes) == Ed25519PointConst.POINT_COORD_BYTE_LEN:
-            try:
-                ed25519_lib.point_decode(point_bytes)
-            except ValueError as ex:
-                raise ValueError("Invalid point bytes") from ex
-            return cls(point_bytes)
-        if len(point_bytes) == Ed25519PointConst.POINT_COORD_BYTE_LEN * 2:
-            if not ed25519_lib.point_is_on_curve(ed25519_lib.point_bytes_to_coord(point_bytes)):
-                raise ValueError("Invalid point bytes")
-            return cls(
-                ed25519_lib.point_encode(point_bytes)
+        if not ed25519_lib.point_is_on_curve(point_bytes):
+            raise ValueError("Invalid point bytes")
+        if ed25519_lib.point_is_decoded_bytes(point_bytes):
+            point_bytes = ed25519_lib.point_encode(
+                ed25519_lib.point_bytes_to_coord(point_bytes)
             )
-        raise ValueError("Invalid point bytes")
+        return cls(point_bytes)
 
     @classmethod
     def FromCoordinates(cls,
@@ -93,7 +90,12 @@ class Ed25519Point(IPoint):
         Args:
             point_bytes (bytes): Point bytes
         """
-        self.m_point = point_bytes
+        if not ed25519_lib.point_is_encoded_bytes(point_bytes):
+            raise ValueError("Invalid point bytes")
+
+        self.m_enc_bytes = point_bytes
+        self.m_is_generator = ed25519_lib.point_is_generator(point_bytes)
+        self.m_x, self.m_y = None, None
 
     @staticmethod
     def CurveType() -> EllipticCurveTypes:
@@ -112,7 +114,7 @@ class Ed25519Point(IPoint):
         Returns:
            Any: Underlying object
         """
-        return self.m_point
+        return self.m_enc_bytes
 
     def X(self) -> int:
         """
@@ -121,7 +123,9 @@ class Ed25519Point(IPoint):
         Returns:
            int: Point X coordinate
         """
-        return ed25519_lib.point_decode_no_check(self.m_point)[0]
+        if self.m_x is None:
+            self.m_x, self.m_y = ed25519_lib.point_bytes_to_coord(self.m_enc_bytes)
+        return self.m_x
 
     def Y(self) -> int:
         """
@@ -130,7 +134,9 @@ class Ed25519Point(IPoint):
         Returns:
            int: Point Y coordinate
         """
-        return ed25519_lib.point_decode_no_check(self.m_point)[1]
+        if self.m_y is None:
+            self.m_x, self.m_y = ed25519_lib.point_bytes_to_coord(self.m_enc_bytes)
+        return self.m_y
 
     def Raw(self) -> DataBytes:
         """
@@ -148,7 +154,7 @@ class Ed25519Point(IPoint):
         Returns:
             DataBytes object: DataBytes object
         """
-        return DataBytes(self.m_point)
+        return DataBytes(self.m_enc_bytes)
 
     def RawDecoded(self) -> DataBytes:
         """
@@ -157,8 +163,7 @@ class Ed25519Point(IPoint):
         Returns:
             DataBytes object: DataBytes object
         """
-        dec = ed25519_lib.point_decode_no_check(self.m_point)
-        return DataBytes(ed25519_lib.encode_int(dec[0]) + ed25519_lib.encode_int(dec[1]))
+        return DataBytes(ed25519_lib.int_encode(self.X()) + ed25519_lib.int_encode(self.Y()))
 
     def __add__(self,
                 point: IPoint) -> IPoint:
@@ -172,7 +177,7 @@ class Ed25519Point(IPoint):
             IPoint object: IPoint object
         """
         return self.__class__(
-            ed25519_nacl_wrapper.point_add(self.m_point, point.UnderlyingObject())
+            ed25519_lib.point_add(self.m_enc_bytes, point.UnderlyingObject())
         )
 
     def __radd__(self,
@@ -199,8 +204,12 @@ class Ed25519Point(IPoint):
         Returns:
             IPoint object: IPoint object
         """
+        if self.m_is_generator:
+            return self.__class__(
+                ed25519_lib.point_scalar_mul_base(scalar)
+            )
         return self.__class__(
-            ed25519_nacl_wrapper.point_mul(scalar, self.m_point)
+            ed25519_lib.point_scalar_mul(scalar, self.m_enc_bytes)
         )
 
     def __rmul__(self,
