@@ -28,7 +28,7 @@ import ed25519_blake2b
 from bip_utils.ecc.common.ikeys import IPrivateKey, IPublicKey
 from bip_utils.ecc.common.ipoint import IPoint
 from bip_utils.ecc.curve.elliptic_curve_types import EllipticCurveTypes
-from bip_utils.ecc.ed25519.ed25519_keys import Ed25519KeysConst
+from bip_utils.ecc.ed25519.ed25519_keys import Ed25519KeysConst, Ed25519PublicKey
 from bip_utils.ecc.ed25519.lib import ed25519_lib
 from bip_utils.ecc.ed25519_blake2b.ed25519_blake2b_point import Ed25519Blake2bPoint
 from bip_utils.utils.misc import BytesUtils, DataBytes
@@ -56,18 +56,16 @@ class Ed25519Blake2bPublicKey(IPublicKey):
         """
 
         # Remove the 0x00 prefix if present
-        if (len(key_bytes) == cls.CompressedLength()
+        if (len(key_bytes) == Ed25519KeysConst.PUB_KEY_BYTE_LEN + len(Ed25519KeysConst.PUB_KEY_PREFIX)
                 and key_bytes[0] == BytesUtils.ToInteger(Ed25519KeysConst.PUB_KEY_PREFIX)):
             key_bytes = key_bytes[1:]
         # The library does not raise any exception in case of length error
-        elif len(key_bytes) != cls.CompressedLength() - 1:
+        elif len(key_bytes) != Ed25519KeysConst.PUB_KEY_BYTE_LEN:
             raise ValueError("Invalid public key bytes")
 
         # The library doesn't check if the point lies on curve
-        try:
-            ed25519_lib.point_decode(key_bytes)
-        except ValueError as ex:
-            raise ValueError("Invalid public key bytes") from ex
+        if not ed25519_lib.point_is_on_curve(key_bytes):
+            raise ValueError("Invalid public key bytes")
 
         return cls(ed25519_blake2b.VerifyingKey(key_bytes))
 
@@ -116,7 +114,7 @@ class Ed25519Blake2bPublicKey(IPublicKey):
         Returns:
            int: Compressed key length
         """
-        return Ed25519KeysConst.PUB_KEY_COMPRESSED_BYTE_LEN
+        return Ed25519PublicKey.CompressedLength()
 
     @staticmethod
     def UncompressedLength() -> int:
@@ -126,7 +124,7 @@ class Ed25519Blake2bPublicKey(IPublicKey):
         Returns:
            int: Uncompressed key length
         """
-        return Ed25519KeysConst.PUB_KEY_UNCOMPRESSED_BYTE_LEN
+        return Ed25519PublicKey.UncompressedLength()
 
     def UnderlyingObject(self) -> Any:
         """
