@@ -2,10 +2,10 @@ from bip_utils.electrum.mnemonic_v1.electrum_v1_entropy_generator import (
     ElectrumV1EntropyBitLen, ElectrumV1EntropyGenerator
 )
 from bip_utils.electrum.mnemonic_v1.electrum_v1_mnemonic import (
-    ElectrumV1Languages, ElectrumV1WordsNum, ElectrumV1Mnemonic
+    ElectrumV1Languages, ElectrumV1Mnemonic, ElectrumV1WordsNum
 )
 from bip_utils.electrum.mnemonic_v1.electrum_v1_mnemonic_decoder import ElectrumV1MnemonicDecoder
 from bip_utils.electrum.mnemonic_v1.electrum_v1_mnemonic_encoder import ElectrumV1MnemonicEncoder
 from bip_utils.electrum.mnemonic_v1.electrum_v1_mnemonic_generator import ElectrumV1MnemonicGenerator
-from bip_utils.electrum.mnemonic_v1.electrum_v1_seed_generator import ElectrumV1SeedGenerator
 from bip_utils.electrum.mnemonic_v1.electrum_v1_mnemonic_validator import ElectrumV1MnemonicValidator
+from bip_utils.electrum.mnemonic_v1.electrum_v1_seed_generator import ElectrumV1SeedGenerator
