@@ -2,10 +2,10 @@ from bip_utils.electrum.mnemonic_v2.electrum_v2_entropy_generator import (
     ElectrumV2EntropyBitLen, ElectrumV2EntropyGenerator
 )
 from bip_utils.electrum.mnemonic_v2.electrum_v2_mnemonic import (
-    ElectrumV2Languages, ElectrumV2WordsNum, ElectrumV2MnemonicTypes, ElectrumV2Mnemonic
+    ElectrumV2Languages, ElectrumV2Mnemonic, ElectrumV2MnemonicTypes, ElectrumV2WordsNum
 )
 from bip_utils.electrum.mnemonic_v2.electrum_v2_mnemonic_decoder import ElectrumV2MnemonicDecoder
 from bip_utils.electrum.mnemonic_v2.electrum_v2_mnemonic_encoder import ElectrumV2MnemonicEncoder
 from bip_utils.electrum.mnemonic_v2.electrum_v2_mnemonic_generator import ElectrumV2MnemonicGenerator
-from bip_utils.electrum.mnemonic_v2.electrum_v2_seed_generator import ElectrumV2SeedGenerator
 from bip_utils.electrum.mnemonic_v2.electrum_v2_mnemonic_validator import ElectrumV2MnemonicValidator
+from bip_utils.electrum.mnemonic_v2.electrum_v2_seed_generator import ElectrumV2SeedGenerator
